diff --git a/Doxy.page.h b/Doxy.page.h
index 50a83ea1bfdfa09bcdb25ec90ba78219f2c6bff8..bf2bc30b989906edee2fe5672afc30b2e160757c 100644
--- a/Doxy.page.h
+++ b/Doxy.page.h
@@ -16,9 +16,9 @@
 \defgroup zoneparser        Zone parser utility
 \defgroup ctl               Control utility
 
-\mainpage CuteDNS API documentation.
+\mainpage Knot API documentation.
 
-CuteDNS is an open-source, high-performace, purely authoritative DNS server.
+Knot is an open-source, high-performace, purely authoritative DNS server.
 
 <h2>Requirements</h2>
 - liburcu (at least 0.4.5): http://lttng.org/urcu
@@ -41,23 +41,23 @@ $ bin/zoneparser -o other-zone.db other-zone.com. other-zone.com.zone
 
 2. Run the server with the compiled zones (use -d to run as a daemon)
 \code
-$ bin/cutedns example.com.db other-zone.db
+$ bin/knot example.com.db other-zone.db
 \endcode
 
-<h3>Using cutectl</h3>
+<h3>Using knotc</h3>
 - This approach currently supports only one zone file.
 - Compiled zone is stored in user's home directory.
 
-1. Add path to cutedns and zonecompiler executables to PATH
+1. Add path to knot and zoneparser executables to PATH
 
 2. Compile zone
 \code
-$ bin/cutectl compile example.com. samples/example.com.zone
+$ bin/knotc compile example.com. samples/example.com.zone
 \endcode
 
 3. Run the server
 \code
-$ bin/cutectl start
+$ bin/knotc start
 \endcode
 
 <h2>Server modules</h2>
diff --git a/src/alloc/malloc.h b/src/alloc/malloc.h
index 1c1807987efefa79eb1b9767de23063bfb613b97..21cb63f4aa691136998fcb09e9d03545b3d6db2b 100644
--- a/src/alloc/malloc.h
+++ b/src/alloc/malloc.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef __CUTEDNS_MALLOC_H__
-#define __CUTEDNS_MALLOC_H__
+#ifndef __KNOT_MALLOC_H__
+#define __KNOT_MALLOC_H__
 
 #include <stdlib.h>
 #include "other/debug.h"
diff --git a/src/alloc/slab.h b/src/alloc/slab.h
index 9bc956f0d878285cebff9f14f16b193df814fd34..49b4c2a19b2165b88dd35755b97ebd9e4227519f 100644
--- a/src/alloc/slab.h
+++ b/src/alloc/slab.h
@@ -67,8 +67,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_SLAB_H_
-#define _CUTEDNS_SLAB_H_
+#ifndef _KNOT_SLAB_H_
+#define _KNOT_SLAB_H_
 
 #include <pthread.h>
 #include <stdint.h>
@@ -329,6 +329,6 @@ void *slab_alloc_realloc(slab_alloc_t* alloc, void *ptr, size_t size);
  */
 void slab_alloc_stats(slab_alloc_t* alloc);
 
-#endif /* _CUTEDNS_SLAB_H_ */
+#endif /* _KNOT_SLAB_H_ */
 
 /*! \} */
diff --git a/src/common.h b/src/common.h
index d21e2f55b33ad1fb85595cb92e7c19c1ae9df0b4..6ff51f53798c52e8889e731ce1540e9c591bc639 100644
--- a/src/common.h
+++ b/src/common.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_COMMON_H_
-#define _CUTEDNS_COMMON_H_
+#ifndef _KNOT_COMMON_H_
+#define _KNOT_COMMON_H_
 
 #include <signal.h>
 #include <stdint.h>
@@ -22,8 +22,9 @@ typedef unsigned int uint;
 
 #define PROJECT_NAME PACKAGE // Project name
 #define PROJECT_VER  0x000100  // 0xMMIIRR (MAJOR,MINOR,REVISION)
-#define PROJECT_EXEC "cutedns" // Project executable
+#define PROJECT_EXEC "knot" // Project executable
 #define ZONEPARSER_EXEC "zoneparser" // Zoneparser executable
+#define PID_FILE "knot.pid"
 
 /* Server. */
 #define CPU_ESTIMATE_MAGIC 2   // Extra threads above the number of processors
@@ -98,6 +99,6 @@ static inline int fread_safe(void *dst, size_t size, size_t n, FILE *fp)
 
 //#define STAT_COMPILE
 
-#endif /* _CUTEDNS_COMMON_H_ */
+#endif /* _KNOT_COMMON_H_ */
 
 /*! @} */
diff --git a/src/ctl/process.c b/src/ctl/process.c
index b78ff68ece1dd235fbce2fbba5297786d3551901..38232193e35b79936d366cc70eb871890d9de134 100644
--- a/src/ctl/process.c
+++ b/src/ctl/process.c
@@ -12,7 +12,7 @@
 char* pid_filename()
 {
 	// Construct filename
-	const char* fn = "/cutedns.pid";
+	const char* fn = PID_FILE;
 	char* home = getenv("HOME");
 	int len = strlen(home) + strlen(fn) + 1;
 	char* ret = malloc(len);
diff --git a/src/ctl/process.h b/src/ctl/process.h
index 180b4a3db9585fe2dd5056c92d91f90b820aa3da..e3a6b89314a9822da801895f747f651078302828 100644
--- a/src/ctl/process.h
+++ b/src/ctl/process.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_PROCESS_H_
-#define _CUTEDNS_PROCESS_H_
+#ifndef _KNOT_PROCESS_H_
+#define _KNOT_PROCESS_H_
 
 #include <unistd.h>
 
@@ -65,4 +65,4 @@ int pid_write(const char* fn);
  */
 int pid_remove(const char* fn);
 
-#endif // _CUTEDNS_PROCESS_H_
+#endif // _KNOT_PROCESS_H_
diff --git a/src/dnslib/consts.h b/src/dnslib/consts.h
index 2ee4ecef06d1f74b3a6760d63eb5532c37e3a3e0..8722814d591d08dc419c59f6193a565646dd08e6 100644
--- a/src/dnslib/consts.h
+++ b/src/dnslib/consts.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_CONSTS_H_
-#define _CUTEDNS_DNSLIB_CONSTS_H_
+#ifndef _KNOT_DNSLIB_CONSTS_H_
+#define _KNOT_DNSLIB_CONSTS_H_
 
 #include <stdint.h>
 #include "dnslib/descriptor.h"
@@ -80,6 +80,6 @@ static const dnslib_rr_type_t
 	DNSLIB_RRTYPE_RT
 };
 
-#endif /* _CUTEDNS_DNSLIB_CONSTS_H_ */
+#endif /* _KNOT_DNSLIB_CONSTS_H_ */
 
 /*! @} */
diff --git a/src/dnslib/debug.h b/src/dnslib/debug.h
index 67bd3d08c75c6f0ae28b54498e51a60a0793c0ce..bd570921eaf8b9be6b66ec61b97a5c9d8e60c936 100644
--- a/src/dnslib/debug.h
+++ b/src/dnslib/debug.h
@@ -8,8 +8,8 @@
  * \addtogroup dnslib
  * @{
  */
-#ifndef _CUTEDNS_DNSLIB_DEBUG_H_
-#define _CUTEDNS_DNSLIB_DEBUG_H_
+#ifndef _KNOT_DNSLIB_DEBUG_H_
+#define _KNOT_DNSLIB_DEBUG_H_
 
 #include <stdint.h>
 #include "dnslib.h"
diff --git a/src/dnslib/descriptor.h b/src/dnslib/descriptor.h
index b7bdf83bc9813595d02a97ddf3ab4b8e8414145c..d9b0cb187dc5fafe511c3f47618ca4581a89379f 100644
--- a/src/dnslib/descriptor.h
+++ b/src/dnslib/descriptor.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_DESCRIPTOR_H_
-#define _CUTEDNS_DNSLIB_DESCRIPTOR_H_
+#ifndef _KNOT_DNSLIB_DESCRIPTOR_H_
+#define _KNOT_DNSLIB_DESCRIPTOR_H_
 
 #include <stdint.h>
 #include <stdbool.h>
@@ -244,7 +244,7 @@ uint16_t dnslib_rrclass_from_string(const char *name);
  */
 size_t dnslib_wireformat_size(uint wire_type);
 
-#endif /* _CUTEDNS_DNSLIB_DESCRIPTOR_H_ */
+#endif /* _KNOT_DNSLIB_DESCRIPTOR_H_ */
 
 /*! @} */
 
diff --git a/src/dnslib/dname.h b/src/dnslib/dname.h
index 123b0b51e58777dc2f20c0181477ddfdeb7d55b5..8bd72d4b6b1d09435c63fa56bb364def3b23cd3f 100644
--- a/src/dnslib/dname.h
+++ b/src/dnslib/dname.h
@@ -8,8 +8,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_DNAME_H_
-#define _CUTEDNS_DNSLIB_DNAME_H_
+#ifndef _KNOT_DNSLIB_DNAME_H_
+#define _KNOT_DNSLIB_DNAME_H_
 
 #include <stdint.h>
 
@@ -260,6 +260,6 @@ int dnslib_dname_compare(const dnslib_dname_t *d1, const dnslib_dname_t *d2);
  */
 dnslib_dname_t *dnslib_dname_cat(dnslib_dname_t *d1, const dnslib_dname_t *d2);
 
-#endif /* _CUTEDNS_DNSLIB_DNAME_H_ */
+#endif /* _KNOT_DNSLIB_DNAME_H_ */
 
 /*! @} */
diff --git a/src/dnslib/edns.h b/src/dnslib/edns.h
index e7f438a936fc87a7c3aac9e09902f6310473e692..8bd25934de1dff8696bf002285fded30186145f9 100644
--- a/src/dnslib/edns.h
+++ b/src/dnslib/edns.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_EDNS_H_
-#define _CUTEDNS_DNSLIB_EDNS_H_
+#ifndef _KNOT_DNSLIB_EDNS_H_
+#define _KNOT_DNSLIB_EDNS_H_
 
 #include <stdint.h>
 
@@ -56,6 +56,6 @@ static inline void dnslib_edns_set_version(uint8_t *edns_wire, uint8_t version)
 	*(edns_wire + DNSLIB_EDNS_OFFSET_VERSION) = version;
 }
 
-#endif /* _CUTEDNS_DNSLIB_EDNS_H_ */
+#endif /* _KNOT_DNSLIB_EDNS_H_ */
 
 /*! @} */
diff --git a/src/dnslib/node.h b/src/dnslib/node.h
index ba05dce9a9b367267279a55404cb00b61b023426..eaf3364b4d19c423032c5feaf5e10dc837179805 100644
--- a/src/dnslib/node.h
+++ b/src/dnslib/node.h
@@ -10,8 +10,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_NODE_H_
-#define _CUTEDNS_DNSLIB_NODE_H_
+#ifndef _KNOT_DNSLIB_NODE_H_
+#define _KNOT_DNSLIB_NODE_H_
 
 #include "dnslib/dname.h"
 #include "lib/skip-list.h"
@@ -187,6 +187,6 @@ void dnslib_node_free_tmp(dnslib_node_t **node, int free_rrsets);
  */
 int dnslib_node_compare(dnslib_node_t *node1, dnslib_node_t *node2);
 
-#endif /* _CUTEDNS_DNSLIB_NODE_H_ */
+#endif /* _KNOT_DNSLIB_NODE_H_ */
 
 /*! @} */
diff --git a/src/dnslib/packet.h b/src/dnslib/packet.h
index 4e9d44a7331470c2389d47118bb334a8be2e853c..f0903b37ee4d5eba4b778a8ef8bc15143f45bfb0 100644
--- a/src/dnslib/packet.h
+++ b/src/dnslib/packet.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_PACKET_H_
-#define _CUTEDNS_DNSLIB_PACKET_H_
+#ifndef _KNOT_DNSLIB_PACKET_H_
+#define _KNOT_DNSLIB_PACKET_H_
 
 #include <stdint.h>
 
@@ -427,6 +427,6 @@ static inline void dnslib_packet_flags_clear_ra(uint8_t *flags2)
 	*flags2 &= ~RA_MASK;
 }
 
-#endif /* _CUTEDNS_DNSLIB_PACKET_H_ */
+#endif /* _KNOT_DNSLIB_PACKET_H_ */
 
 /*! @} */
diff --git a/src/dnslib/rdata.h b/src/dnslib/rdata.h
index 7b128c20d1f1a778f18eaf80bb2a7e5a4b0958ea..b2128ce85a2dff6c942bdcb98e9f1abc1c16c1f0 100644
--- a/src/dnslib/rdata.h
+++ b/src/dnslib/rdata.h
@@ -10,8 +10,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_RDATA_H_
-#define _CUTEDNS_DNSLIB_RDATA_H_
+#ifndef _KNOT_DNSLIB_RDATA_H_
+#define _KNOT_DNSLIB_RDATA_H_
 
 #include <stdint.h>
 
@@ -234,6 +234,6 @@ const dnslib_dname_t *dnslib_rdata_dname_target(const dnslib_rdata_t *rdata);
 const dnslib_dname_t *dnslib_rdata_get_name(const dnslib_rdata_t *rdata,
                                             uint16_t type);
 
-#endif /* _CUTEDNS_DNSLIB_RDATA_H */
+#endif /* _KNOT_DNSLIB_RDATA_H */
 
 /*! @} */
diff --git a/src/dnslib/response.h b/src/dnslib/response.h
index c379a08cc20fb1793397e2440ced346b796842c2..017912b61546a598aa1bd7239ed94b457875b66f 100644
--- a/src/dnslib/response.h
+++ b/src/dnslib/response.h
@@ -11,8 +11,8 @@
  * \addtogroup dnslib
  * @{
  */
-#ifndef _CUTEDNS_DNSLIB_RESPONSE_H_
-#define _CUTEDNS_DNSLIB_RESPONSE_H_
+#ifndef _KNOT_DNSLIB_RESPONSE_H_
+#define _KNOT_DNSLIB_RESPONSE_H_
 
 #include <stdint.h>
 #include <string.h>
@@ -336,6 +336,6 @@ void dnslib_response_free(dnslib_response_t **response);
 
 void dnslib_response_dump(const dnslib_response_t *resp);
 
-#endif /* _CUTEDNS_DNSLIB_RESPONSE_H_ */
+#endif /* _KNOT_DNSLIB_RESPONSE_H_ */
 
 /*! @} */
diff --git a/src/dnslib/rrset.h b/src/dnslib/rrset.h
index 277a69ad0de6f5f2cfdf0d2819a2399bd788fd8c..b085515ee6e4ae814a100c1ca74e0ea026bc8046 100644
--- a/src/dnslib/rrset.h
+++ b/src/dnslib/rrset.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_RRSET_H_
-#define _CUTEDNS_DNSLIB_RRSET_H_
+#ifndef _KNOT_DNSLIB_RRSET_H_
+#define _KNOT_DNSLIB_RRSET_H_
 
 #include <stdint.h>
 
@@ -211,6 +211,6 @@ void dnslib_rrset_deep_free(dnslib_rrset_t **rrset, int free_owner,
  */
 int dnslib_rrset_merge(void **r1, void **r2);
 
-#endif /* _CUTEDNS_DNSLIB_RRSET_H_ */
+#endif /* _KNOT_DNSLIB_RRSET_H_ */
 
 /*! @} */
diff --git a/src/dnslib/rrsig.h b/src/dnslib/rrsig.h
index e91ce3578bb2f92109e8d439941efc01670b3c5e..c94c68d5aca7b09c000457b5aa311f8059e5f708 100644
--- a/src/dnslib/rrsig.h
+++ b/src/dnslib/rrsig.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_RRSIG_H_
-#define _CUTEDNS_DNSLIB_RRSIG_H_
+#ifndef _KNOT_DNSLIB_RRSIG_H_
+#define _KNOT_DNSLIB_RRSIG_H_
 
 #include <stdint.h>
 
@@ -157,6 +157,6 @@ void dnslib_rrsig_set_deep_free(dnslib_rrsig_set_t **rrsigs, int free_owner,
  */
 int dnslib_rrsig_set_merge(void **r1, void **r2);
 
-#endif /* _CUTEDNS_DNSLIB_RRSIG_H_ */
+#endif /* _KNOT_DNSLIB_RRSIG_H_ */
 
 /*! @} */
diff --git a/src/dnslib/tolower.h b/src/dnslib/tolower.h
index 2209d36c0db520ca5ed23d319bbc689140108c6d..669088bdc127bead6e570b0700e87332ad52d948 100644
--- a/src/dnslib/tolower.h
+++ b/src/dnslib/tolower.h
@@ -10,8 +10,8 @@
 
 #include <stdint.h>
 
-#ifndef _CUTEDNS_DNSLIB_TOLOWER_H_
-#define _CUTEDNS_DNSLIB_TOLOWER_H_
+#ifndef _KNOT_DNSLIB_TOLOWER_H_
+#define _KNOT_DNSLIB_TOLOWER_H_
 
 enum {
 	CHAR_TABLE_SIZE = 256
@@ -281,4 +281,4 @@ static inline uint8_t dnslib_tolower(uint8_t c) {
 	return char_table[c];
 }
 
-#endif /* _CUTEDNS_DNSLIB_TOLOWER_H_ */
+#endif /* _KNOT_DNSLIB_TOLOWER_H_ */
diff --git a/src/dnslib/utils.h b/src/dnslib/utils.h
index 4ba4bebfe5ce8ae86dca19aea1d9638a0be93831..56a17a0ff6d5235fda4caf4bfe1e889065cb9c72 100644
--- a/src/dnslib/utils.h
+++ b/src/dnslib/utils.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_UTILS_H_
-#define _CUTEDNS_DNSLIB_UTILS_H_
+#ifndef _KNOT_DNSLIB_UTILS_H_
+#define _KNOT_DNSLIB_UTILS_H_
 
 #include <string.h>
 
@@ -71,7 +71,7 @@ static inline void dnslib_wire_write_u32(uint8_t *pos, uint32_t data)
 	pos[3] = (uint8_t)(data & 0xff);
 }
 
-#endif /* _CUTEDNS_DNSLIB_UTILS_H_ */
+#endif /* _KNOT_DNSLIB_UTILS_H_ */
 
 /*! @} */
 
diff --git a/src/dnslib/zone-dump.h b/src/dnslib/zone-dump.h
index 05e99babd299a8f0201b7386175a32cb1a99cbc5..e99c7c369b332206235ed722b4e95f46c84a4a16 100644
--- a/src/dnslib/zone-dump.h
+++ b/src/dnslib/zone-dump.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_ZONEDUMP_H_
-#define _CUTEDNS_DNSLIB_ZONEDUMP_H_
+#ifndef _KNOT_DNSLIB_ZONEDUMP_H_
+#define _KNOT_DNSLIB_ZONEDUMP_H_
 
 #include "dnslib/zone.h"
 
diff --git a/src/dnslib/zone-load.h b/src/dnslib/zone-load.h
index ac4915c78b554463c0ba96275341d01c668a4b80..d4e216f48af49003726020a4aaea39ccac84a745 100644
--- a/src/dnslib/zone-load.h
+++ b/src/dnslib/zone-load.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_ZONELOAD_H_
-#define _CUTEDNS_DNSLIB_ZONELOAD_H_
+#ifndef _KNOT_DNSLIB_ZONELOAD_H_
+#define _KNOT_DNSLIB_ZONELOAD_H_
 
 #include "dnslib/zone.h"
 
@@ -23,5 +23,5 @@
  */
 dnslib_zone_t *dnslib_zload_load(const char *filename);
 
-#endif /* _CUTEDNS_ZONELOAD_H_ */
+#endif /* _KNOT_ZONELOAD_H_ */
 
diff --git a/src/dnslib/zone.h b/src/dnslib/zone.h
index 36668a8317ac46375c2160ab9d9ff8ee160eda5b..efbf0526dccf095aabf09ae85e5085f32edbd16e 100644
--- a/src/dnslib/zone.h
+++ b/src/dnslib/zone.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_ZONE_H_
-#define _CUTEDNS_DNSLIB_ZONE_H_
+#ifndef _KNOT_DNSLIB_ZONE_H_
+#define _KNOT_DNSLIB_ZONE_H_
 
 #include "dnslib/node.h"
 #include "dnslib/dname.h"
diff --git a/src/dnslib/zonedb.c b/src/dnslib/zonedb.c
index 9b6a205f49501fa20b2747e75ffd6990f707ac00..29fc67b52d854ccdc4e5d87148fbd5d0199edad6 100644
--- a/src/dnslib/zonedb.c
+++ b/src/dnslib/zonedb.c
@@ -147,7 +147,7 @@ void dnslib_zonedb_deep_free(dnslib_zonedb_t **db)
 char* dnslib_zonedb_dbpath()
 {
 	// Construct filename
-	const char* fn = "/cutedns.zdb";
+	const char* fn = "/knot.zdb";
 	char* home = getenv("HOME");
 	int len = strlen(home) + strlen(fn) + 1;
 	char* ret = malloc(len);
diff --git a/src/dnslib/zonedb.h b/src/dnslib/zonedb.h
index bb47d7d07a30185c429b60c5d27bed27ef7f3649..3a30c06a08c4615f0fb6ab3ad70c684d9fe2e318 100644
--- a/src/dnslib/zonedb.h
+++ b/src/dnslib/zonedb.h
@@ -12,8 +12,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DNSLIB_ZONEDB_H_
-#define _CUTEDNS_DNSLIB_ZONEDB_H_
+#ifndef _KNOT_DNSLIB_ZONEDB_H_
+#define _KNOT_DNSLIB_ZONEDB_H_
 
 #include "lib/skip-list.h"
 #include "dnslib/zone.h"
@@ -102,6 +102,6 @@ char* dnslib_zonedb_dbpath();
 
 /*----------------------------------------------------------------------------*/
 
-#endif /* _CUTEDNS_DNSLIB_ZONEDB_H_ */
+#endif /* _KNOT_DNSLIB_ZONEDB_H_ */
 
 /*! @} */
diff --git a/src/hash/cuckoo-hash-table.h b/src/hash/cuckoo-hash-table.h
index 941637c2391780945dc37a1eee024501d70c8961..595358041541ba5cc6f22d564cd44d5d26d25f59 100644
--- a/src/hash/cuckoo-hash-table.h
+++ b/src/hash/cuckoo-hash-table.h
@@ -18,8 +18,8 @@
  * \addtogroup hashing
  * @{
  */
-#ifndef _CUTEDNS_CUCKOO_HASH_TABLE_H_
-#define _CUTEDNS_CUCKOO_HASH_TABLE_H_
+#ifndef _KNOT_CUCKOO_HASH_TABLE_H_
+#define _KNOT_CUCKOO_HASH_TABLE_H_
 
 #include <stdint.h> /* uint32_t */
 #include <stdlib.h> /* size_t */
@@ -272,6 +272,6 @@ void ck_dump_table(const ck_hash_table_t *table);
 
 /*----------------------------------------------------------------------------*/
 
-#endif /* _CUTEDNS_CUCKOO_HASH_TABLE_H_ */
+#endif /* _KNOT_CUCKOO_HASH_TABLE_H_ */
 
 /*! @} */
diff --git a/src/hash/hash-functions.h b/src/hash/hash-functions.h
index 58a2291fb20eb33e7f895536c693faaf5012026e..e52e6d6ddbfacbe1126c8210c8ab6df468237191 100644
--- a/src/hash/hash-functions.h
+++ b/src/hash/hash-functions.h
@@ -13,8 +13,8 @@
  * @}
  */
 
-#ifndef _CUTEDNS_HASH_FUNCTIONS_H_
-#define _CUTEDNS_HASH_FUNCTIONS_H_
+#ifndef _KNOT_HASH_FUNCTIONS_H_
+#define _KNOT_HASH_FUNCTIONS_H_
 
 typedef  unsigned long int  u4;   /* unsigned 4-byte type */
 typedef  unsigned     char  u1;   /* unsigned 1-byte type */
@@ -33,6 +33,6 @@ unsigned long djb_hash(const unsigned char *key, int size);
 
 unsigned long elf_hash(const unsigned char *key, int size);
 
-#endif /* _CUTEDNS_HASH_FUNCTIONS_H_ */
+#endif /* _KNOT_HASH_FUNCTIONS_H_ */
 
 /*! @} */
diff --git a/src/hash/universal-system.h b/src/hash/universal-system.h
index 684b403adaccc9b45d514466d179b1c75ced1be8..42f827cdefae638ad6c6b24c3f05610023384fdf 100644
--- a/src/hash/universal-system.h
+++ b/src/hash/universal-system.h
@@ -23,8 +23,8 @@
  * \addtogroup hashing
  * @}
  */
-#ifndef _CUTEDNS_UNIVERSAL_SYSTEM_H_
-#define _CUTEDNS_UNIVERSAL_SYSTEM_H_
+#ifndef _KNOT_UNIVERSAL_SYSTEM_H_
+#define _KNOT_UNIVERSAL_SYSTEM_H_
 
 #include <stdint.h>
 
@@ -68,6 +68,6 @@ uint32_t us_hash(uint32_t value, uint table_exp, uint fnc, uint generation);
 
 /*----------------------------------------------------------------------------*/
 
-#endif /* _CUTEDNS_UNIVERSAL_SYSTEM_H_ */
+#endif /* _KNOT_UNIVERSAL_SYSTEM_H_ */
 
 /*! @} */
diff --git a/src/lib/dynamic-array.h b/src/lib/dynamic-array.h
index c598a630a48a2a38112fbec74a65a4acdb9fccf4..bd27e298aff138f815a5e271761fe68d84a555d6 100644
--- a/src/lib/dynamic-array.h
+++ b/src/lib/dynamic-array.h
@@ -12,8 +12,8 @@
  * \addtogroup data_structures
  * @{
  */
-#ifndef _CUTEDNS_DYNAMIC_ARRAY_H_
-#define _CUTEDNS_DYNAMIC_ARRAY_H_
+#ifndef _KNOT_DYNAMIC_ARRAY_H_
+#define _KNOT_DYNAMIC_ARRAY_H_
 
 #include <string.h>
 #include <pthread.h>
@@ -135,6 +135,6 @@ uint da_get_count(const da_array_t *array);
 
 /*----------------------------------------------------------------------------*/
 
-#endif /* _CUTEDNS_DYNAMIC_ARRAY_H_ */
+#endif /* _KNOT_DYNAMIC_ARRAY_H_ */
 
 /*! @} */
diff --git a/src/lib/skip-list.h b/src/lib/skip-list.h
index cf3a98c6a953ea04ecd3053187725a1737935f88..220605fa1c0b8db249ec6dcdfffdd2d95ff4f177 100644
--- a/src/lib/skip-list.h
+++ b/src/lib/skip-list.h
@@ -41,8 +41,8 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 Retrieved from: http://en.literateprograms.org/Skip_list_(C)?oldid=12811
 */
 
-#ifndef _CUTEDNS_SKIP_LIST_H_
-#define _CUTEDNS_SKIP_LIST_H_
+#ifndef _KNOT_SKIP_LIST_H_
+#define _KNOT_SKIP_LIST_H_
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -196,6 +196,6 @@ const skip_node_t *skip_next(const skip_node_t *node);
 void skip_print_list(const skip_list_t *list,
                      void (*print_item)(void *, void *));
 
-#endif /* _CUTEDNS_SKIP_LIST_H_ */
+#endif /* _KNOT_SKIP_LIST_H_ */
 
 /*! \} */
diff --git a/src/main.c b/src/main.c
index 4a8cd8f1e09f3748fc608e7a86dad5ddc4f9102b..8e2548119478331c4990d57600783224197777f6 100644
--- a/src/main.c
+++ b/src/main.c
@@ -11,7 +11,7 @@
 /*----------------------------------------------------------------------------*/
 
 static volatile short s_stopping = 0;
-static cute_server *s_server = NULL;
+static server_t *s_server = NULL;
 
 // SIGINT signal handler
 void interrupt_handle(int s)
@@ -31,7 +31,7 @@ void interrupt_handle(int s)
 	if (s == SIGINT || s == SIGTERM) {
 		if (s_stopping == 0) {
 			s_stopping = 1;
-			cute_stop(s_server);
+			server_stop(s_server);
 		} else {
 			log_error("\nOK! OK! Exiting immediately.\n");
 			exit(1);
@@ -138,11 +138,11 @@ int main(int argc, char **argv)
 	}
 
 	// Create server instance
-	s_server = cute_create();
+	s_server = server_create();
 
 	// Run server
 	int res = 0;
-	if ((res = cute_start(s_server, zfs, zfs_count)) == 0) {
+	if ((res = server_start(s_server, zfs, zfs_count)) == 0) {
 
 		// Register service and signal handler
 		struct sigaction sa;
@@ -161,7 +161,7 @@ int main(int argc, char **argv)
 			res = chdir("/");
 		}
 
-		if ((res = cute_wait(s_server)) != 0) {
+		if ((res = server_wait(s_server)) != 0) {
 			log_error("There was an error while waiting for server"
 				  " to finish.\n");
 		}
@@ -176,7 +176,7 @@ int main(int argc, char **argv)
 	}
 
 	// Stop server and close log
-	cute_destroy(&s_server);
+	server_destroy(&s_server);
 
 	// Remove PID file if daemonized
 	if (daemonize) {
diff --git a/src/other/debug.h b/src/other/debug.h
index 79a478eade1a2498dd995ab4c94cff2234859418..94443e3bc1d9c6d1e4f1ef32e9f6204e69d7d6e9 100644
--- a/src/other/debug.h
+++ b/src/other/debug.h
@@ -8,8 +8,8 @@
  * \addtogroup debugging
  * @{
  */
-#ifndef _CUTEDNS_DEBUG_H_
-#define _CUTEDNS_DEBUG_H_
+#ifndef _KNOT_DEBUG_H_
+#define _KNOT_DEBUG_H_
 
 #include "other/log.h"
 
@@ -183,6 +183,6 @@
 #define debug_mem(msg...)
 #endif
 
-#endif /* _CUTEDNS_DEBUG_H_ */
+#endif /* _KNOT_DEBUG_H_ */
 
 /*! @} */
diff --git a/src/other/log.h b/src/other/log.h
index 3b5dda78837e2b545188667ad63345ea987a70be..c8e74f1c71a891970baf8c3f6a2aa88bee8104c8 100644
--- a/src/other/log.h
+++ b/src/other/log.h
@@ -14,8 +14,8 @@
  * \addtogroup logging
  * @{
  */
-#ifndef _CUTEDNS_LOG_H_
-#define _CUTEDNS_LOG_H_
+#ifndef _KNOT_LOG_H_
+#define _KNOT_LOG_H_
 
 /*
  */
@@ -69,6 +69,6 @@ int print_msg(int level, const char *msg, ...) __attribute__((format(printf, 2,
 #define log_info(msg...)      log_msg(LOG_INFO, msg)
 #define log_debug(msg...)     log_msg(LOG_DEBUG, msg)
 
-#endif /* _CUTEDNS_LOG_H_ */
+#endif /* _KNOT_LOG_H_ */
 
 /*! @} */
diff --git a/src/other/print.h b/src/other/print.h
index a7f4adf82498339b1e22e1f06e90ca08ca0617c2..0e5a08fcbb87826fd4e1866a86a75b278371826b 100644
--- a/src/other/print.h
+++ b/src/other/print.h
@@ -12,8 +12,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_PRINT_H_
-#define _CUTEDNS_PRINT_H_
+#ifndef _KNOT_PRINT_H_
+#define _KNOT_PRINT_H_
 
 typedef int (*printf_t)(const char *fmt, ...);
 
@@ -29,6 +29,6 @@ void hex_printf(const char *data, int length, printf_t print_handler);
 void bit_print(const char *data, int length);
 void bit_printf(const char *data, int length, printf_t print_handler);
 
-#endif /* _CUTEDNS_PRINT_H_ */
+#endif /* _KNOT_PRINT_H_ */
 
 /*! @} */
diff --git a/src/server/dthreads.h b/src/server/dthreads.h
index ffbe7c0493636d0b8a492aeaf4fb54f88410c467..c3027cd1d4ec80c3a6a7819dd12b60cd9f10ad41 100644
--- a/src/server/dthreads.h
+++ b/src/server/dthreads.h
@@ -21,8 +21,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_DTHREADS_H_
-#define _CUTEDNS_DTHREADS_H_
+#ifndef _KNOT_DTHREADS_H_
+#define _KNOT_DTHREADS_H_
 
 #include <pthread.h>
 
@@ -325,7 +325,7 @@ int dt_unit_lock(dt_unit_t *unit);
  */
 int dt_unit_unlock(dt_unit_t *unit);
 
-#endif // _CUTEDNS_DTHREADS_H_
+#endif // _KNOT_DTHREADS_H_
 
 /*! @} */
 
diff --git a/src/server/name-server.h b/src/server/name-server.h
index 42ec5c5e988e322473b2cc92b395169486cec0ea..0e59f8e1baa2daad0288da34cbf19f13c2f6f6a1 100644
--- a/src/server/name-server.h
+++ b/src/server/name-server.h
@@ -17,8 +17,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_NAME_SERVER_H_
-#define _CUTEDNS_NAME_SERVER_H_
+#ifndef _KNOT_NAME_SERVER_H_
+#define _KNOT_NAME_SERVER_H_
 
 #include <stdint.h>
 
@@ -82,7 +82,7 @@ int ns_answer_request(ns_nameserver *nameserver,
  */
 void ns_destroy(ns_nameserver **nameserver);
 
-#endif /* _CUTEDNS_NAME_SERVER_H_ */
+#endif /* _KNOT_NAME_SERVER_H_ */
 
 /*! @} */
 
diff --git a/src/server/server.c b/src/server/server.c
index c0e2e429531af73a00057a5c24c58b5b39c43080..946396bec8b3f65231cbd2154b43332213b98170 100644
--- a/src/server/server.c
+++ b/src/server/server.c
@@ -15,7 +15,7 @@
 #include "dnslib/debug.h"
 #include "dnslib/dname.h"
 
-cute_server *cute_create()
+server_t *server_create()
 {
 	// Create TCP+UDP sockets
 	debug_server("Binding sockets..\n");
@@ -35,7 +35,7 @@ cute_server *cute_create()
 	debug_server("Done\n\n");
 
 	// Create server structure
-	cute_server *server = malloc(sizeof(cute_server));
+	server_t *server = malloc(sizeof(server_t));
 	server->handlers = NULL;
 	server->state = ServerIdle;
 	if (server == NULL) {
@@ -71,7 +71,7 @@ cute_server *cute_create()
 	// Create socket handlers
 	debug_server("Creating UDP workers..\n");
 	dt_unit_t *unit = dt_create_coherent(thr_count, &udp_master, 0);
-	cute_create_handler(server, udp_sock, unit);
+	server_create_handler(server, udp_sock, unit);
 	debug_server("Done\n\n");
 
 	// Create TCP handlers
@@ -83,14 +83,14 @@ cute_server *cute_create()
 	debug_server("Creating TCP workers..\n");
 	unit = dt_create(tcp_unit_size);
 	dt_repurpose(unit->threads[0], &tcp_master, 0);
-	cute_create_handler(server, tcp_sock, unit);
+	server_create_handler(server, tcp_sock, unit);
 
 	debug_server("Done\n\n");
 
 	return server;
 }
 
-iohandler_t *cute_create_handler(cute_server *server, int fd, dt_unit_t *unit)
+iohandler_t *server_create_handler(server_t *server, int fd, dt_unit_t *unit)
 {
 	// Create new worker
 	iohandler_t *handler = malloc(sizeof(iohandler_t));
@@ -122,7 +122,7 @@ iohandler_t *cute_create_handler(cute_server *server, int fd, dt_unit_t *unit)
 	return handler;
 }
 
-int cute_remove_handler(cute_server *server, iohandler_t *ref)
+int server_remove_handler(server_t *server, iohandler_t *ref)
 {
 	// Find worker
 	iohandler_t *w = 0, *p = 0;
@@ -162,7 +162,7 @@ int cute_remove_handler(cute_server *server, iohandler_t *ref)
 	return 0;
 }
 
-int cute_start(cute_server *server, char **filenames, uint zones)
+int server_start(server_t *server, char **filenames, uint zones)
 {
 	// Check server
 	if (server == 0) {
@@ -201,7 +201,7 @@ int cute_start(cute_server *server, char **filenames, uint zones)
 	return ret;
 }
 
-int cute_wait(cute_server *server)
+int server_wait(server_t *server)
 {
 	// Wait for dispatchers to finish
 	int ret = 0;
@@ -209,14 +209,14 @@ int cute_wait(cute_server *server)
 		debug_server("server: [%p] joining threading unit\n",
 			     server->handlers);
 		ret += dt_join(server->handlers->unit);
-		cute_remove_handler(server, server->handlers);
+		server_remove_handler(server, server->handlers);
 		debug_server("server: joined threading unit\n");
 	}
 
 	return ret;
 }
 
-void cute_stop(cute_server *server)
+void server_stop(server_t *server)
 {
 	// Notify servers to stop
 	server->state &= ~ServerRunning;
@@ -226,7 +226,7 @@ void cute_stop(cute_server *server)
 	}
 }
 
-void cute_destroy(cute_server **server)
+void server_destroy(server_t **server)
 {
 	// Check server
 	if (!server) {
@@ -240,7 +240,7 @@ void cute_destroy(cute_server **server)
 	iohandler_t *w = (*server)->handlers;
 	while (w != NULL) {
 		iohandler_t *n = w->next;
-		cute_remove_handler(*server, w);
+		server_remove_handler(*server, w);
 		w = n;
 	}
 
diff --git a/src/server/socket.h b/src/server/socket.h
index 5b4414d3b9f0033052ee319d8efa628296972c94..62dceca3948f1e9ab8673b365a4a7a336d81c98b 100644
--- a/src/server/socket.h
+++ b/src/server/socket.h
@@ -12,8 +12,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_SOCKET_H_
-#define _CUTEDNS_SOCKET_H_
+#ifndef _KNOT_SOCKET_H_
+#define _KNOT_SOCKET_H_
 
 /* POSIX only. */
 #include <sys/socket.h>
@@ -137,7 +137,7 @@ ssize_t socket_sendto(int socket, const void *buf, size_t len, int flags,
  */
 int socket_close(int socket);
 
-#endif // _CUTEDNS_SOCKET_H_
+#endif // _KNOT_SOCKET_H_
 
 /*! @} */
 
diff --git a/src/server/tcp-handler.h b/src/server/tcp-handler.h
index 40bda8033dac54502de899c85f219eb06a252296..374dbe2a2c3d07f4071b0292c826dac97ba3d214 100644
--- a/src/server/tcp-handler.h
+++ b/src/server/tcp-handler.h
@@ -13,8 +13,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_TCPHANDLER_H_
-#define _CUTEDNS_TCPHANDLER_H_
+#ifndef _KNOT_TCPHANDLER_H_
+#define _KNOT_TCPHANDLER_H_
 
 #include "server/socket.h"
 #include "server/server.h"
@@ -35,7 +35,7 @@
  */
 int tcp_master(dthread_t *thread);
 
-#endif // _CUTEDNS_TCPHANDLER_H_
+#endif // _KNOT_TCPHANDLER_H_
 
 /*! @} */
 
diff --git a/src/server/udp-handler.h b/src/server/udp-handler.h
index 6546ec9348b44802fee3f889c8751e7ce332b3be..88b39e36357b6c7bb20e197ebddf2a1bc5ba9269 100644
--- a/src/server/udp-handler.h
+++ b/src/server/udp-handler.h
@@ -13,8 +13,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_UDPHANDLER_H_
-#define _CUTEDNS_UDPHANDLER_H_
+#ifndef _KNOT_UDPHANDLER_H_
+#define _KNOT_UDPHANDLER_H_
 
 #include "server/socket.h"
 #include "server/server.h"
diff --git a/src/stat/gatherer.h b/src/stat/gatherer.h
index fb63ae9f8634aebdcfcdb512cb568810c1efb2b6..e2bce345169a8f8a75525ab7095bbd6e95a3fec4 100644
--- a/src/stat/gatherer.h
+++ b/src/stat/gatherer.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_GATHERER_H_
-#define _CUTEDNS_GATHERER_H_
+#ifndef _KNOT_GATHERER_H_
+#define _KNOT_GATHERER_H_
 
 #include <stdint.h>
 
@@ -90,6 +90,6 @@ gatherer_t *new_gatherer();
  */
 void gatherer_free(gatherer_t *gatherer);
 
-#endif /* _CUTEDNS_STAT_GATHERER_H_ */
+#endif /* _KNOT_STAT_GATHERER_H_ */
 
 /*! @} */
diff --git a/src/stat/stat.h b/src/stat/stat.h
index 3124fe5785dc4ca13db631c29c6a917045c05f30..0fd66f0915a8ac5a945646b33afc39e3d056f967 100644
--- a/src/stat/stat.h
+++ b/src/stat/stat.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_STAT_H_
-#define _CUTEDNS_STAT_H_
+#ifndef _KNOT_STAT_H_
+#define _KNOT_STAT_H_
 
 #include <time.h>
 #include <stdbool.h>
@@ -132,6 +132,6 @@ void stat_static_gath_free();
 static inline void stat_static_gath_free() {}
 #endif /* STAT_COMPILE */
 
-#endif /* _CUTEDNS_STAT_H_ */
+#endif /* _KNOT_STAT_H_ */
 
 /*! @} */
diff --git a/src/tests/server_tests.c b/src/tests/server_tests.c
index cfbcbf9d1bc224d5ceee83bf9c18fed2ecb08648..6203701205b1a29013cdd619af8e421d0257ca6f 100644
--- a/src/tests/server_tests.c
+++ b/src/tests/server_tests.c
@@ -20,27 +20,27 @@ unit_api server_tests_api = {
 static const int SERVER_TEST_COUNT = 4;
 
 /*! Test: create server. */
-cute_server *test_server_create()
+server_t *test_server_create()
 {
-	return cute_create();
+	return server_create();
 }
 
 /*! Test: start server. */
-int test_server_start(cute_server *s, char **filenames, uint zones)
+int test_server_start(server_t *s, char **filenames, uint zones)
 {
-	return cute_start(s, filenames, zones) == 0;
+	return server_start(s, filenames, zones) == 0;
 }
 
 /*! Test: finish server. */
-int test_server_finish(cute_server *s)
+int test_server_finish(server_t *s)
 {
-	return cute_wait(s) == 0;
+	return server_wait(s) == 0;
 }
 
 /*! Test: stop server. */
-int test_server_destroy(cute_server *s)
+int test_server_destroy(server_t *s)
 {
-	cute_destroy(&s);
+	server_destroy(&s);
 	return s == 0;
 }
 
@@ -58,7 +58,7 @@ static void interrupt_handle(int s)
 /*! API: run tests. */
 static int server_tests_run(int argc, char *argv[])
 {
-	cute_server *server = 0;
+	server_t *server = 0;
 	int ret = 0;
 
 	// Register service and signal handler
@@ -81,7 +81,7 @@ static int server_tests_run(int argc, char *argv[])
 	//! Test server exit code
 	ok(ret, "server: started ok");
 	if (ret) {
-		cute_stop(server);
+		server_stop(server);
 	} else {
 		diag("server crashed, skipping deinit and destroy tests");
 	}
diff --git a/src/tests/tap_unit.h b/src/tests/tap_unit.h
index bdff169571dec157c99a0548b5648144e6176ad0..bad329931fa9f0a4e4ca20acc4069b3536d25d28 100644
--- a/src/tests/tap_unit.h
+++ b/src/tests/tap_unit.h
@@ -10,8 +10,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_TAP_UNIT_H_
-#define _CUTEDNS_TAP_UNIT_H_
+#ifndef _KNOT_TAP_UNIT_H_
+#define _KNOT_TAP_UNIT_H_
 
 #include "tests/libtap/tap.h"
 
@@ -31,7 +31,7 @@ typedef struct {
 	unitapi_f  *run;   /*!< Function to run unit tests. */
 } unit_api;
 
-#endif // _CUTEDNS_TAP_UNIT_H_
+#endif // _KNOT_TAP_UNIT_H_
 
 /*! @} */
 
diff --git a/src/zoneparser/parser-descriptor.h b/src/zoneparser/parser-descriptor.h
index ee002aa08a2320a25e3704971b53fb85152ec834..8eb6fc3bcf7e9b39851faa8c9dcf5d304a81a872 100644
--- a/src/zoneparser/parser-descriptor.h
+++ b/src/zoneparser/parser-descriptor.h
@@ -9,8 +9,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_PARSER_DESCRIPTOR_H_
-#define _CUTEDNS_PARSER_DESCRIPTOR_H_
+#ifndef _KNOT_PARSER_DESCRIPTOR_H_
+#define _KNOT_PARSER_DESCRIPTOR_H_
 
 #include <stdint.h>
 #include <stdbool.h>
@@ -237,7 +237,7 @@ const char *parser_rrclass_to_string(uint16_t rrclass);
  */
 uint16_t parser_rrclass_from_string(const char *name);
 
-#endif /* _CUTEDNS_PARSER_DESCRIPTOR_H_ */
+#endif /* _KNOT_PARSER_DESCRIPTOR_H_ */
 
 /*! @} */
 
diff --git a/src/zoneparser/parser-util.h b/src/zoneparser/parser-util.h
index 47fdac3d532fb6b59a2e41fb8b3c99de12a8bf77..eaf96665af56e2bf0ae92323f4e3e2fe96494b3c 100644
--- a/src/zoneparser/parser-util.h
+++ b/src/zoneparser/parser-util.h
@@ -11,8 +11,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_PARSER_UTIL_H_
-#define _CUTEDNS_PARSER_UTIL_H_
+#ifndef _KNOT_PARSER_UTIL_H_
+#define _KNOT_PARSER_UTIL_H_
 
 #include <assert.h>
 #include <fcntl.h>
@@ -60,6 +60,6 @@ uint32_t strtottl(const char *nptr, const char **endptr);
 
 time_t mktime_from_utc(const struct tm *tm);
 
-#endif /* _CUTEDNS_PARSER_UTIL_H_ */
+#endif /* _KNOT_PARSER_UTIL_H_ */
 
 /*! @} */
diff --git a/src/zoneparser/zoneparser.h b/src/zoneparser/zoneparser.h
index 8a435cb1cbd321caf50ab15f4e3d1bba6f51fbc9..113147c947cd6da67b693c04808195e1be84249a 100644
--- a/src/zoneparser/zoneparser.h
+++ b/src/zoneparser/zoneparser.h
@@ -12,8 +12,8 @@
  * @{
  */
 
-#ifndef _CUTEDNS_ZONEPARSER_H_
-#define _CUTEDNS_ZONEPARSER_H_
+#ifndef _KNOT_ZONEPARSER_H_
+#define _KNOT_ZONEPARSER_H_
 
 #include <stdio.h>
 
@@ -155,6 +155,6 @@ void zparser_init(const char *filename, uint32_t ttl, uint16_t rclass,
 
 void zparser_free();
 
-#endif /* _CUTEDNS_ZONEPARSER_H_ */
+#endif /* _KNOT_ZONEPARSER_H_ */
 
 /*! @} */
diff --git a/src/server/server.h b/src/server/server.h
index 5b445b866bc9ae039e779818d6636bb3bccf335f..25c234c5a2fb4718bc71e140805b9ee0047f2e45 100644
--- a/src/server/server.h
+++ b/src/server/server.h
@@ -5,7 +5,7 @@
  *
  * \brief Core server functions.
  *
  * Contains the main high-level server structure (cute_server) and interface
  * to functions taking care of proper initialization of the server and clean-up
  * when terminated.
  *
@@ -16,14 +16,16 @@
  * \addtogroup server
  * @{
  */
-#ifndef _CUTEDNS_SERVER_H_
-#define _CUTEDNS_SERVER_H_
+#ifndef _KNOT_SERVER_H_
+#define _KNOT_SERVER_H_
 
 #include "server/name-server.h"
 #include "server/socket.h"
 #include "server/dthreads.h"
 #include "dnslib/zonedb.h"
 
+struct server;
+
 /*! \brief I/O handler structure.
   */
 typedef struct iohandler_t {
@@ -32,7 +34,7 @@ typedef struct iohandler_t {
 	unsigned           state;   /*!< Handler state */
 	struct iohandler_t *next;   /*!< Next handler */
 	dt_unit_t          *unit;   /*!< Threading unit */
-	struct cute_server *server; /*!< Reference to server */
+	struct server *server; /*!< Reference to server */
 
 } iohandler_t;
 
@@ -49,7 +51,7 @@ typedef enum {
 } server_state;
 
 /* Forwad declarations. */
-struct cute_server;
+
 struct iohandler_t;
 
 /*!
@@ -57,7 +59,7 @@ struct iohandler_t;
  *
  * Keeps references to all important structures needed for operation.
  */
-typedef struct cute_server {
+typedef struct server {
 
 	/*! \brief Server state tracking. */
 	unsigned state;
@@ -71,7 +73,7 @@ typedef struct cute_server {
 	/*! \brief I/O handlers list. */
 	struct iohandler_t *handlers;
 
-} cute_server;
+} server_t;
 
 /*!
  * \brief Allocates and initializes the server structure.
@@ -81,7 +83,7 @@ typedef struct cute_server {
  * \retval New instance if successful.
  * \retval 0 If an error occured.
  */
-cute_server *cute_create();
+server_t *server_create();
 
 /*!
  * \brief Create and bind handler to given filedescriptor.
@@ -96,7 +98,7 @@ cute_server *cute_create();
  * \retval Handler instance if successful.
  * \retval 0 If an error occured.
  */
-iohandler_t *cute_create_handler(cute_server *server, int fd, dt_unit_t *unit);
+iohandler_t *server_create_handler(server_t *server, int fd, dt_unit_t *unit);
 
 /*!
  * \brief Delete handler.
@@ -109,7 +111,7 @@ iohandler_t *cute_create_handler(cute_server *server, int fd, dt_unit_t *unit);
  * \retval  0 On success.
  * \retval <0 If an error occured.
  */
-int cute_remove_handler(cute_server *server, iohandler_t *ref);
+int server_remove_handler(server_t *server, iohandler_t *ref);
 
 /*!
  * \brief Starts the server.
@@ -123,7 +125,7 @@ int cute_remove_handler(cute_server *server, iohandler_t *ref);
  * \todo When a module for configuration is added, the filename parameter will
  *       be removed.
  */
-int cute_start(cute_server *server, char **filenames, uint zones);
+int server_start(server_t *server, char **filenames, uint zones);
 
 /*!
  * \brief Waits for the server to finish.
@@ -133,23 +135,23 @@ int cute_start(cute_server *server, char **filenames, uint zones);
  * \retval  0 On success.
  * \retval <0 If an error occured.
  */
-int cute_wait(cute_server *server);
+int server_wait(server_t *server);
 
 /*!
  * \brief Requests server to stop.
  *
  * \param server Server structure to be used for operation.
  */
-void cute_stop(cute_server *server);
+void server_stop(server_t *server);
 
 /*!
  * \brief Properly destroys the server structure.
  *
  * \param server Server structure to be used for operation.
  */
-void cute_destroy(cute_server **server);
+void server_destroy(server_t **server);
 
-#endif // _CUTEDNS_SERVER_H_
+#endif // _KNOT_SERVER_H_
 
 /*! @} */
 
@@ -5,7 +5,7 @@
  * \brief Core server functions.
  *
- * Contains the main high-level server structure (cute_server) and interface
+ * Contains the main high-level server structure (server_t) and interface
  * to functions taking care of proper initialization of the server and clean-up
  * when terminated.